/**
 * MEDOR: Middleware Enabling Distributed Object Requests
 * 
 * Copyright (C) 2001-2003 France Telecom R&D
 * Contact: alexandre.lefebvre@rd.francetelecom.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Initial developers: M. Alia, A. Lefebvre
 */
package org.objectweb.medor.expression.lib;

import org.objectweb.medor.expression.api.Expression;
import org.objectweb.medor.expression.api.Operator;
import org.objectweb.medor.expression.api.TypingException;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.Date;

public class DivideBy extends BasicBinaryArithmeticOperator {

    private static final long serialVersionUID = 8115928471067985393L;

    public DivideBy() {
    }

    public DivideBy(Expression l, Expression r) {
		super(l, r);
    }

    public int evaluate(int op1, int op2) {
        return op1 / op2;
    }

    public int evaluate(int op1, short op2) {
        return op1 / op2;
    }

    public long evaluate(int op1, long op2) {
        return op1 / op2;
    }

    public float evaluate(int op1, float op2) {
        return op1 / op2;
    }

    public double evaluate(int op1, double op2) {
        return op1 / op2;
    }

    public float evaluate(float op1, float op2) {
        return op1 / op2;
    }

    public float evaluate(float op1, short op2) {
        return op1 / op2;
    }

    public float evaluate(float op1, int op2) {
        return op1 / op2;
    }

    public float evaluate(float op1, long op2) {
        return op1 / op2;
    }

    public double evaluate(float op1, double op2) {
        return op1 / op2;
    }

    public int evaluate(char op1, char op2) {
        return op1 / op2;
    }

    public long evaluate(long op1, long op2) {
        return op1 / op2;
    }

    public long evaluate(long op1, short op2) {
        return op1 / op2;
    }

    public long evaluate(long op1, int op2) {
        return op1 / op2;
    }

    public float evaluate(long op1, float op2) {
        return op1 / op2;
    }

    public double evaluate(long op1, double op2) {
        return op1 / op2;
    }

    public double evaluate(double op1, double op2) {
        return op1 / op2;
    }

    public double evaluate(double op1, short op2) {
        return op1 / op2;
    }

    public double evaluate(double op1, int op2) {
        return op1 / op2;
    }

    public double evaluate(double op1, float op2) {
        double res = op1 / op2;
        return res;
    }

    public double evaluate(double op1, long op2) {
        return op1 / op2;
    }

    public BigDecimal evaluate(BigDecimal op1, BigDecimal op2) {
        return op1.divide(op2, BigDecimal.ROUND_UNNECESSARY);
    }

    public BigInteger evaluate(BigInteger op1, BigInteger op2) {
        return op1.mod(op2);
    }

    public String evaluate(String op1, String op2) throws TypingException {
        throw new TypingException("div(String, String)?");
    }

    public String evaluate(String op1, char op2) throws TypingException {
        throw new TypingException("div(String, Char)?");
    }

    public String evaluate(char op1, String op2) throws TypingException {
        throw new TypingException("div(char, String)?");
    }

    public Timestamp evaluate(Timestamp op1, Timestamp op2)
            throws TypingException {
        throw new TypingException("div(Timestamp, Timestamp)?");
    }

    public Time evaluate(Time op1, Time op2) throws TypingException {
        throw new TypingException("div(Time, Time)?");
    }

    public Date evaluate(Date op1, Date op2) throws TypingException {
        throw new TypingException("div(Date, Date)?");
    }

	public String getOperatorString() {
		return Operator.DIV;
	}

}
