/**
 * MEDOR: Middleware Enabling Distributed Object Requests
 * 
 * Copyright (C) 2001-2003 France Telecom R&D
 * Contact: alexandre.lefebvre@rd.francetelecom.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Initial developers: M. Alia, A. Lefebvre
 */
package org.objectweb.medor.expression.lib;

import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.type.api.PTypeSpace;
import org.objectweb.medor.expression.api.Expression;
import org.objectweb.medor.expression.api.ExpressionException;
import org.objectweb.medor.expression.api.MalformedExpressionException;
import org.objectweb.medor.expression.api.Operand;
import org.objectweb.medor.expression.api.Operator;
import org.objectweb.medor.expression.api.ParameterOperand;
import org.objectweb.medor.expression.api.TypingException;

/**
 * Operator representing the substring extraction given a String, a first
 * integer to start from and a second integer indicating the length of the
 * required substring.
 */
public class Substring extends BasicOperator {

    private static final long serialVersionUID = -338079340195983186L;

    /**
	 * Constructs the operator
	 * @param inputString is the String from which to extract the substing
	 * @param start is the index of the first character in the String to start
	 * with. It is expected that 1 is the first character in the string (and
	 * not 0 like in Java).
	 * @param length is the size of the requested substring
	 */
    public Substring(Expression inputString, Expression start,
					 Expression length) {
		super(PTypeSpace.STRING, new Expression[]{inputString, start, length});
    }

    public Substring() {
		super(PTypeSpace.STRING);
    }

	public Operand evaluate(ParameterOperand[] pos, Object o)
		throws ExpressionException {
        if (result == null) {
            throw new ExpressionException("Unevaluable Expression: May not be compiled");
        }
        result.setValue(
					evaluate(
							getExpression(0).evaluate(pos, o).getString(),
							getExpression(1).evaluate(pos, o).getInt(),
							getExpression(2).evaluate(pos, o).getInt()));
		return result;
	}


    public Operand compileExpression()
            throws ExpressionException, MalformedExpressionException {
        compileExpression();
        checkOperands(new PType[][]{
                {PTypeSpace.STRING, PTypeSpace.STRING, PTypeSpace.INT},
        });
        verified = true;
        result = new BasicVariableOperand(type);
		return result;
    }

    public String evaluate(String op, int start, int length) {
        return op.substring(start-1, length + start-1);
    }

    public String getOperatorString() {
        return Operator.SUBSTRING;
    }
}
