/**
 * MEDOR: Middleware Enabling Distributed Object Requests
 * 
 * Copyright (C) 2001-2003 France Telecom R&D
 * Contact: alexandre.lefebvre@rd.francetelecom.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Initial developers: M. Alia, S. Chassande-Barrioz, A. Lefebvre
 */
package org.objectweb.medor.expression.type;

import org.objectweb.jorm.type.api.PType;
import org.objectweb.medor.expression.api.TypingException;

/**
 * @author A. Lefebvre
 */
public class ExpressionTypeHelper {
	/**
	 * This method tells if a given Type is an arithmetic type
	 * @param t The PType to be checked.
	 * @return true if the tested PType is an arithmetic type.
	 */
	public static final boolean isArithmeticType(PType t) {
		switch (t.getTypeCode()) {
		case PType.TYPECODE_BYTE:
		case PType.TYPECODE_OBJBYTE:
			return true;
		case PType.TYPECODE_SHORT:
		case PType.TYPECODE_OBJSHORT:
			return true;
		case PType.TYPECODE_INT:
		case PType.TYPECODE_OBJINT:
			return true;
		case PType.TYPECODE_LONG:
		case PType.TYPECODE_OBJLONG:
			return true;
		case PType.TYPECODE_FLOAT:
		case PType.TYPECODE_OBJFLOAT:
			return true;
		case PType.TYPECODE_DOUBLE:
		case PType.TYPECODE_OBJDOUBLE:
			return true;
		default:
			return false;
		}
	}

	/**
	 * This method returns the type which would result from applying a binary
	 * operator to 2 objects of given PType.
	 * If the two PTypes are incompatible, a TypingException is thrown.
	 * @param type1 The PType of the first object.
	 * @param type2 The PType of the second object.
	 * @return The PType of the result.
	 */
	public static PType getResultType(PType type1, PType type2)
		throws TypingException {
		if (type1.isa(type2)) {
			return type2;
		}
		else if (type2.isa(type1)) {
			return type1;
		}
		else {
			throw new TypingException("Incompatible types");
		}
	}
}
